@@ -2,78 +2,76 @@ package threads::lite::list;
 
 use strict;
 use warnings;
-use 5.010;
 use Exporter 5.57 qw/import/;
 
-our @EXPORT_OK = qw/parallel_map parallel_grep/;
+our @EXPORT_OK = qw/parallel_map/;
 
-use threads::lite qw/self spawn receive receiveq/;
-use constant DEFAULT_THREADS => 4;
-use Carp qw/carp/;
+use threads::lite;
 
-our $VERSION = '0.031_001';
-our $THREADS ||= DEFAULT_THREADS;
+our $VERSION = $threads::lite::VERSION;
+
+our $THREADS = 4;
 
 sub _mapper {
-	my (undef, $filter) = receiveq('filter', qr//);
+	my (undef, $filter) = receive('filter');
 	my $continue = 1;
 	while ($continue) {
-		receive {
-			when (@$_ == 4) {
-				my ($manager, undef, $index, $value) = @$_;
+		receive_table(
+			[ qr/thread=\d+/, 'map' ] => sub {
+				my ($manager, undef, $index, $value) = @_;
 				local $_ = $value;
 				$manager->send(self, 'map', $index, $filter->());
-			}
-			when (['kill']) {
+			},
+			[ 'kill' ] => sub {
 				$continue = 0;
+			},
+			[] => sub {
+				warn sprintf "Received something unknown: (%s)\n", join ',', @_;
 			}
-			default {
-				carp sprintf "Received something unknown: (%s)\n", join ',', @$_;
-			}
-		};
+		);
 	}
 	return;
 }
 
 sub _receive_next {
 	my $threads = shift;
-	my ($thread, undef, $index, @value) = receiveq($threads, 'map', qr//, qr//);
+	my ($thread, undef, $index, @value) = receive($threads, 'map');
 	return ($thread, $index, @value);
 }
 
 sub new {
-	my $class   = shift;
+	my $class = shift;
 	my %options = (
 		modules => [],
 		threads => $THREADS,
 		@_,
 	);
 	my @modules = ('threads::lite::list', @{ $options{modules} });
-	my %threads = map { ($_->id => $_) } spawn({ modules => \@modules, monitor => 1, pool_size => $options{threads} }, 'threads::lite::list::_mapper');
+	my %threads = map { ( $_->id => $_ ) }
+		threads::lite->spawn({ modules => \@modules, monitor => 1 , pool_size => $options{threads}}, 'threads::lite::list::_mapper' );
 	$_->send(filter => $options{code}) for values %threads;
 	return bless \%threads, $class;
 }
 
 sub map {
 	my ($self, @args) = @_;
-	my $i = 0;
-	my @ret;
+	my ($i, @ret) = 0;
 
-	my $id      = self;
-	my %threads = %{$self};
+	my $id = self;
+	my %threads = %{ $self };
 	for my $thread (values %threads) {
 		last if $i == @args;
 		$thread->send($id, 'map', $i, $args[$i]);
 		$i++;
 	}
 	while ($i < @args) {
-		my ($thread, $index, @value) = _receive_next([ values %threads ]);
+		my ($thread, $index, @value) = _receive_next( [ values %threads ] );
 		$ret[$index] = \@value;
 		$thread->send($id, 'map', $i, $args[$i]);
 		$i++;
 	}
 	while (%threads) {
-		my ($thread, $index, @value) = _receive_next([ values %threads ]);
+		my ($thread, $index, @value) = _receive_next( [ values %threads ] );
 		$ret[$index] = \@value;
 		delete $threads{ $thread->id };
 	}
@@ -93,26 +91,30 @@ sub grep {
 	return @ret;
 }
 
-## no critic (Subroutines::ProhibitSubroutinePrototypes)
-
 sub parallel_map(&@) {
 	my ($code, $options, @args) = @_;
-	my $object = __PACKAGE__->new(($options ? %{$options} : ()), code => $code);
+
+	my $object = __PACKAGE__->new(
+		($options ? %{$options} : ()),
+		code => $code
+	);
 	return $object->map(@args);
 }
 
 sub parallel_grep(&@) {
 	my ($code, $options, @args) = @_;
-	my $object = __PACKAGE__->new(($options ? %{$options} : ()), code => $code);
+
+	my $object = __PACKAGE__->new(
+		($options ? %{$options} : ()),
+		code => $code
+	);
 	return $object->grep(@args);
 }
 
 sub DESTROY {
 	my $self = shift;
-	for my $thread (values %{$self}) {
+	for my $thread (values %{ $self }) {
 		$thread->send('kill');
-		receiveq('exit', qr//, $thread->id, undef);
-		delete $self->{ $thread->id };
 	}
 	return;
 }
@@ -125,11 +127,13 @@ threads::lite::list - Threaded list utilities
 
 =head1 VERSION
 
-Version 0.031_001
+Version 0.020
 
 =head1 SYNOPSIS
 
-This module implements some parallel list utilities op top of threads::lite.
+This module implements threads for perl. One crucial difference with normal threads is that the threads are B<entirely> disconnected, except by message queues (channel). It thus facilitates a message passing style of multi-threading.
+
+=head1 CLASS METHODS
 
 =head1 FUNCTIONS
 
@@ -141,7 +145,7 @@ map a list using multiple threads. $options is a hashref whose keys are like in
 
 grep a list using multiple threads. $options is a hashref whose keys are like in C<new>.
 
-=head1 CLASS METHODS
+=head1 METHODS
 
 A parallel list processing object can be created if you want to reuse your filter with other arguments.
 
@@ -165,8 +169,6 @@ The number of threads you want to use to do the mapping. The default is currentl
 
 =back
 
-=head1 INSTANCE METHODS
-
 =head2 map(@elements)
 
 Map elements in a parallel manner.
