@@ -4,33 +4,35 @@ use strict;
 use warnings;
 use Scalar::Util qw/blessed/;
 
-use overload '~~' => sub {
-	my ($self, $other, $reverse) = @_;
-	if (blessed($other) && $other->isa(__PACKAGE__)) {
-		return $self->id == $other->id;
-	}
-	else {
-		return $self eq $other;
-	}
-  },
-  '""' => sub {
-	my $self = shift;
-	return "thread=${$self}";
-  },
-  'eq' => sub {
-	my ($self, $other, $reverse) = @_;
-	($self, $other) = ($other, $self) if $reverse;
-	return "$self" ~~ $other;
-  };
+use overload 
+	'~~' => sub { 
+		my ($self, $other, $reverse) = @_;
+#		($self, $other) = ($other, $self) if $reverse;
+		if (blessed($other) && $other->isa(__PACKAGE__)) {
+			return $self->id == $other->id;
+		}
+		else {
+			return $self eq $other;
+		}
+	},
+	'""' => sub {
+		my $self = shift;
+		return "thread=${$self}";
+	},
+	'eq' => sub {
+		my ($self, $other, $reverse) = @_;
+		($self, $other) = ($other, $self) if $reverse;
+		return "$self" ~~ $other;
+	};
 
 use threads::lite qw/self receive/;
 
-our $VERSION = '0.031_001';
+our $VERSION = $threads::lite::VERSION;
 
 sub rpc {
 	my ($self, @arguments) = @_;
 	$self->send(self, @arguments);
-	my (undef, @ret) = receiveq($self);
+	my (undef, @ret) = receive($self);
 	return (@ret);
 }
 
@@ -49,7 +51,7 @@ threads::lite::tid - a threads::lite thread id
 
 =head1 VERSION
 
-Version 0.031_001
+Version 0.010
 
 =head1 SYNOPSIS
 
@@ -61,13 +63,13 @@ This module represents a thread ID object. It provides a handle to a thread.
 
 Send a message to a thread. The message items may contain any data type that can be serialized by L<Storable> (including coderefs).
 
-=head2 id()
+=head2 id
 
-Get an opaque but primitive identifier for thread.
+Get the numerical id of this thread.
 
-=head2 monitor()
+=head2 monitor
 
-Monitor the thread. This will cause the calling thread to get a notification of the thread's end. In case of a natural death it returns C<('exit', 'normal', $id, @return_value)>, in case of an unnatural death it will contain C<('exit', 'error', $id, $exception)>.
+Monitor the thread. This will cause the calling thread to get a notification of the thread's end. In case of a natural death it returns C<('normal', @return_value)>, in case of an unnatural death it will contain C<('error', $exception)>.
 
 =head2 rpc(@args)
 
@@ -85,12 +87,16 @@ Please report any bugs or feature requests to C<bug-threads-lite at rt.cpan.org>
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=threads-lite>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+
+
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc threads::lite
 
+
 You can also look for information at:
 
 =over 4
@@ -113,6 +119,10 @@ L<http://search.cpan.org/dist/threads-lite>
 
 =back
 
+
+=head1 ACKNOWLEDGEMENTS
+
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009, 2010 Leon Timmermans, all rights reserved.
